# lynyrd


[![PyPI - Version](https://img.shields.io/pypi/v/lynyrd.svg)](https://pypi.org/project/lynyrd)


Animation to go along with Free Bird

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
uvenv install lynyrd
```

## Usage
```bash
lynyrd
# or,
python -m lynyrd
```

Then, at `localhost:8347` you should be able to see the app.

## License

`lynyrd` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
